@@ -1,7 +1,7 @@
 package Git::Bunch;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2015-11-05'; # DATE
+our $VERSION = '0.50'; # VERSION
 
 use 5.010001;
 use strict;
@@ -604,6 +604,17 @@ sshfs-mounted filesystem, while -rlptD succeeds, so by default we don't maintain
 ownership. If you need to maintain ownership (e.g. you run as root and the repos
 are not owned by root), turn this option on.
 
+_
+        },
+        rsync_del => {
+            summary => 'Whether to use --del rsync option',
+            schema => 'bool',
+            description => <<'_',
+
+When rsync-ing non-repos, by default `--del` option is not used for more safety
+because rsync is a one-way action. To add rsync `--del` option, enable this
+option.
+
 _
         },
         create_bare_target => {
@@ -722,7 +733,8 @@ sub sync_bunch {
             # target, we use /^deleting /x
             my $uuid = UUID::Random::generate();
             my $v = $log->is_debug ? "-v" : "";
-            $cmd = "rsync --log-format=$uuid -${a}z $v --del --force ".
+            my $del = $args{rsync_del} ? "--del" : "";
+            $cmd = "rsync --log-format=$uuid -${a}z $v $del --force ".
                 shell_quote("$source/$e")." .";
             my ($stdout, @result) = Capture::Tiny::capture_stdout(
                 sub { system($cmd) });
@@ -886,7 +898,7 @@ Git::Bunch - Manage gitbunch directory (directory which contain git repos)
 
 =head1 VERSION
 
-This document describes version 0.49 of Git::Bunch (from Perl distribution Git-Bunch), released on 2015-09-09.
+This document describes version 0.50 of Git::Bunch (from Perl distribution Git-Bunch), released on 2015-11-05.
 
 =head1 SYNOPSIS
 
@@ -939,6 +951,8 @@ report which repositories are clean/unclean.
 
 Will die if can't chdir into bunch or git repository.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1036,6 +1050,8 @@ Execute a command for each repo in the bunch.
 For each git repository in the bunch, will chdir to it and execute specified
 command.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1141,6 +1157,8 @@ manually.
 
 For all other non-git repos, will simply synchronize by one-way rsync.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1213,6 +1231,14 @@ Specify regex pattern of repos to include.
 
 Only process a single repo.
 
+=item * B<rsync_del> => I<bool>
+
+Whether to use --del rsync option.
+
+When rsync-ing non-repos, by default C<--del> option is not used for more safety
+because rsync is a one-way action. To add rsync C<--del> option, enable this
+option.
+
 =item * B<rsync_opt_maintain_ownership> => I<bool> (default: 0)
 
 Whether or not, when rsync-ing from source, we use -a (= -rlptgoD) or -rlptD (-a minus -go).
